@@ -209,7 +209,7 @@ around app_test => sub ( $orig, $self ) {
 
     my $out = P->pm->run_capture( $self->alien_bin_path, '-t', '-c', $self->alien_cfg_path );
 
-    say $out;
+    say $LF, $out;
 
     if ( $out =~ /test\hfailed/sm ) {
         say 'FAILED';
